==> tabular-data-column-widget-1.3.0-20140905.110141-118-servicearchive.tar.gz: org/gcube/portlets/user/td/columnwidget/client/LabelColumnDialog.java <==
package org.gcube.portlets.user.td.columnwidget.client;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

import com.google.web.bindery.event.shared.EventBus;
import com.sencha.gxt.widget.core.client.Window;
import com.sencha.gxt.widget.core.client.event.SelectEvent;
import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
import com.sencha.gxt.widget.core.client.form.ComboBox;

/**
 * Delete Column Dialog
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class LabelColumnDialog extends Window {
	protected int WIDTH=400;
	protected int HEIGHT=120;
	protected TRId trId;
	protected ComboBox<ColumnData> combo = null;
	protected String columnName = null;
	protected EventBus eventBus;
	
	public LabelColumnDialog(TRId trId,  EventBus eventBus) {
		create(trId, null, eventBus);
	}

	public LabelColumnDialog(TRId trId, String columnName,  EventBus eventBus) {
		create(trId, columnName, eventBus);
	}

	protected void create(TRId trId, String columnName,  EventBus eventBus) {
		this.trId = trId;
		this.columnName = columnName;
		this.eventBus=eventBus;
		initWindow();
		
		LabelColumnPanel labelColumnPanel= new LabelColumnPanel(trId, columnName, eventBus);
		add(labelColumnPanel);
	}
	
	protected void initWindow() {
		setWidth(WIDTH);
		setHeight(HEIGHT);
		setBodyBorder(false);
		setResizable(false);
		setHeadingText("Label Columns");
		//getHeader().setIcon(Resources.IMAGES.side_list());
	}
	
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void initTools() {
		super.initTools();

		closeBtn.addSelectHandler(new SelectHandler() {

			public void onSelect(SelectEvent event) {
				close();
			}
		});

	}

	public void close() {
		hide();

	}
	
}

==> tabular-data-column-widget-1.10.0-20191021.145759-8-servicearchive.tar.gz: org/gcube/portlets/user/td/columnwidget/client/LabelColumnDialog.java <==
package org.gcube.portlets.user.td.columnwidget.client;

import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;

import com.google.gwt.core.client.GWT;
import com.google.web.bindery.event.shared.EventBus;
import com.sencha.gxt.widget.core.client.Window;
import com.sencha.gxt.widget.core.client.event.SelectEvent;
import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;

/**
 * Delete Column Dialog
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public class LabelColumnDialog extends Window {
	private static final int WIDTH=400;
	private static final int HEIGHT=120;
	private LabelColumnMessages msgs;
	
	
	public LabelColumnDialog(TRId trId,  EventBus eventBus) {
		create(trId, null, eventBus);
	}

	public LabelColumnDialog(TRId trId, String columnName,  EventBus eventBus) {
		create(trId, columnName, eventBus);
	}

	protected void create(TRId trId, String columnName,  EventBus eventBus) {
		initMessages();
		initWindow();
		
		LabelColumnPanel labelColumnPanel= new LabelColumnPanel(trId, columnName, eventBus);
		add(labelColumnPanel);
	}
	
	protected void initMessages(){
		msgs = GWT.create(LabelColumnMessages.class);
	}
	
	
	
	protected void initWindow() {
		setWidth(WIDTH);
		setHeight(HEIGHT);
		setBodyBorder(false);
		setResizable(false);
		setHeadingText(msgs.dialogHeadingText());
	}
	
	
	/**
	 * {@inheritDoc}
	 */
	@Override
	protected void initTools() {
		super.initTools();

		closeBtn.addSelectHandler(new SelectHandler() {

			public void onSelect(SelectEvent event) {
				close();
			}
		});

	}

	public void close() {
		hide();

	}
	
}
